###################################
### Segmented linear regression ###
##################################
library(segmented)
library(ggplot2)

## Import data set: -> All_countries_LC_Pop_YCap into work space.

### Need to manually input each country into the script, for the analysis.

### LANDED CATCH ###
### To assess the landed catch data -> "countryname"_LC_T or countryname"_LC_Kg
### To assess landed catch in tonnes use LC_T or in kilogrmas use LC_Kg 

### YIELD PER CAPITA ###
### To assess yield per capita for the coastal population (40% of total population)
### us "countryname"_y_Cap


### STEP 1 ###
####
df <- All_countries_LC_Pop_YCap

p <- ggplot(df, aes(x = Year, y = Algeria_y_cap)) + geom_line()
p

### y is where either landed catch (LC) or yiled per capita (y_Cap) needs to be changed in the lines above after the country name to switch between analyses

p <- p + labs(x = "Years", y = "Yield per capita")
p

### y can be changed to "Landed catch" where required

### STEP 2 ###

# create a linear model
my.lm <- lm(Algeria_y_cap ~ Year, data = df)
summary(my.lm)

# a linear model with data after the breakpoint. Evaluate the graphic output to determine an approximate breakpoint, place date in "df" or can leave as df
my.lm2 <- lm(Algeria_y_cap ~ Year, data = df)
summary(my.lm2)

### STEP 3 ###
# Provide an estimated breakpoint for the model (XXXX)
# after looking a the data, 
my.seg <- segmented(my.lm, 
                    seg.Z = ~ Year, 
                    psi = list(Year = c(1973)))

# display the summary
summary(my.seg)

# this function provides the breakpoint, compares your estimate to the models and provides a standard error fo rth emodel prediction
my.seg$psi

# Get the slopes - is the change positive or negative
slope(my.seg)

## Davies test post hoc test to determine the validility of the model. The 'best' breakpoint is an estimate from across 10 points and may not be the most accurate. 
davies.test(my.lm, seg.Z=~Year)
